@@ -1,15 +1,20 @@
 # http://djangosnippets.org/snippets/1378/
 
-from django.core.urlresolvers import RegexURLResolver, RegexURLPattern, \
-    Resolver404, get_resolver
+from django.core.urlresolvers import RegexURLPattern, Resolver404, get_resolver
 
 __all__ = ('resolve_to_name',)
 
 
+def _dispatch(pattern, path):
+    if isinstance(pattern, RegexURLPattern):
+        return _pattern_resolve_to_name(pattern, path)
+    else:
+        return _resolver_resolve_to_name(pattern, path)
+
 def _pattern_resolve_to_name(self, path):
     match = self.regex.search(path)
     if match:
-        name = ""
+        name = ''
         if self.name:
             name = self.name
         elif hasattr(self, '_callback_str'):
@@ -27,7 +32,7 @@ def _resolver_resolve_to_name(self, path):
         new_path = path[match.end():]
         for pattern in self.url_patterns:
             try:
-                name = pattern.resolve_to_name(new_path)
+                name = _dispatch(pattern, new_path)
             except Resolver404, e:
                 tried.extend([(pattern.regex.pattern + '   ' + t) for t in \
                         e.args[0]['tried']])
@@ -38,10 +43,6 @@ def _resolver_resolve_to_name(self, path):
         raise Resolver404, {'tried': tried, 'path': new_path}
 
 
-# here goes monkeypatching
-RegexURLPattern.resolve_to_name = _pattern_resolve_to_name
-RegexURLResolver.resolve_to_name = _resolver_resolve_to_name
-
-
 def resolve_to_name(path, urlconf=None):
-    return get_resolver(urlconf).resolve_to_name(path)
+    r = get_resolver(urlconf)
+    return _dispatch(r, path)
